// This mod-file estimates a slightly augmented RBC model.

var n y c k x eta_b eta_a eta_x;

varexo eps_b eps_a eps_x;

parameters A theta delta beta rho_b rho_a rho_x ;

A=2.3;
theta=0.36;
delta=0.025;
beta=0.99;
rho_b=0.5;
rho_a=0.5;
rho_x=0.5;


model(linear);
# y_k = (1/theta)*(1/beta-1+delta);
# c_k = y_k-delta;
n=y-c;
c=-eta_b(+1)+eta_b+(1-delta)*beta*eta_x(+1)-eta_x+c(+1)-theta*beta*y_k*y(+1)+theta*beta*y_k*k;
y=eta_a+theta*k(-1)+(1-theta)*n;
k=delta*x+(1-delta)*k(-1)+delta*eta_x;
x=(y_k/delta)*y-(c_k/delta)*c;
eta_b=rho_b*eta_b(-1)+eps_b;
eta_a=rho_a*eta_a(-1)+eps_a;
eta_x=rho_x*eta_x(-1)+eps_x;
end;

shocks;
var eps_b; stderr 0.02;
var eps_a; stderr 0.02;
var eps_x; stderr 0.02;
end;

three_shock_estimation_steadystate;

steady;

check; 

estimated_params;
A, normal_pdf, 2, 0.3;
theta, beta_pdf, 0.3, 0.1;
beta, beta_pdf, 0.99, 0.001;
delta, beta_pdf, 0.025, 0.005;
rho_a, beta_pdf, 0.7, 0.15;
rho_b, beta_pdf, 0.7, 0.15;
rho_x, beta_pdf, 0.7, 0.15;
stderr eps_a, inv_gamma_pdf, 0.02, inf;
stderr eps_b, inv_gamma_pdf, 0.02, inf;
stderr eps_x, inv_gamma_pdf, 0.02, inf;
end;

varobs y n c;

global lgx_TeX_ lgy_TeX_ ;

lgx_TeX_ = '\epsilon_a'; 

lgx_TeX_ = strvcat(lgx_TeX_,'\epsilon_b'); 

lgx_TeX_ = strvcat(lgx_TeX_,'\epsilon_x'); 


lgy_TeX_ = 'c'; 

lgy_TeX_ = strvcat(lgy_TeX_,'\eta_a'); 

lgy_TeX_ = strvcat(lgy_TeX_,'\eta_b'); 

lgy_TeX_ = strvcat(lgy_TeX_,'eta_x'); 

lgy_TeX_ = strvcat(lgy_TeX_,'k'); 

lgy_TeX_ = strvcat(lgy_TeX_,'n');

lgy_TeX_ = strvcat(lgy_TeX_,'x');

lgy_TeX_ = strvcat(lgy_TeX_,'y');

estim_params_.tex = 'A'; 

estim_params_.tex = strvcat(estim_params_.tex,'\theta'); 

estim_params_.tex = strvcat(estim_params_.tex,'\beta'); 

estim_params_.tex = strvcat(estim_params_.tex,'\delta'); 

estim_params_.tex = strvcat(estim_params_.tex,'\rho_a'); 

estim_params_.tex = strvcat(estim_params_.tex,'\rho_b'); 

estim_params_.tex = strvcat(estim_params_.tex,'\rho_x'); 


options_.varobs_TeX = 'y'; 

options_.varobs_TeX = strvcat(options_.varobs_TeX,'n'); 
options_.varobs_TeX = strvcat(options_.varobs_TeX,'c');


//Further options you can set inside the brackets include: 
//nodiagnostic, mode_file=three_shock_estimation_mode, 
//mode_compute=0, forecast=5,load_mh_file, filtered_var, smoother 



estimation(datafile=simuldata, mode_check, mh_replic=20000, 
mh_nblocks=2, mh_jscale=0.43); 
